@@ -3,7 +3,7 @@
 #' @description
 #' Transform a supertibble into an XLSX file, with each REDCap data tibble in a separate sheet.
 #'
-#' @param supertbl A supertibble generated using `read_redcap()`.
+#' @param supertbl A supertibble generated using [read_redcap()].
 #' @param file The name of the file to which the output will be written.
 #' @param add_labelled_column_headers If `TRUE`, the first row of each sheet will contain variable labels,
 #' with variable names in the second row. If `FALSE`, variable names will be in the first row.
@@ -207,8 +207,8 @@ write_redcap_xlsx <- function(supertbl,
 #' @description
 #' Helper function to support `labelled` aesthetics to XLSX supertibble output
 #'
-#' @param supertbl a supertibble generated using `read_redcap()`
-#' @param supertbl_meta supertibble metadata generated by `bind_supertbl_metadata()`
+#' @param supertbl a supertibble generated using [read_redcap()]
+#' @param supertbl_meta supertibble metadata generated by [bind_supertbl_metadata()]
 #' @param wb An `openxlsx2` workbook object
 #' @param sheet_vals Helper argument passed from `write_redcap_xlsx` to
 #' determine and assign sheet values.
@@ -230,7 +230,7 @@ add_labelled_xlsx_features <- function(supertbl,
                                        supertbl_toc = NULL) {
   check_installed("labelled", reason = "to make use of labelled features in `write_redcap_xlsx`")
   # Generate variable labels off of labelled dictionary objects ----
-  generate_dictionaries <- function(x) {
+  generate_dictionaries <- function(x) { #nolint: object_usage_linter
     labelled::generate_dictionary(x) %>%
       select("variable", "label") %>%
       mutate(label = if_else(is.na(.data$label), "", .data$label)) %>%
@@ -284,7 +284,7 @@ add_labelled_xlsx_features <- function(supertbl,
   }
 
   # Define redcap_data variable labels
-  var_labels <- supertbl$redcap_data %>% map(\(x) generate_dictionaries(x))
+  var_labels <- map(.x = supertbl$redcap_data, ~generate_dictionaries(.x))
 
   for (i in seq_along(supertbl$redcap_form_name)) {
     wb$add_data(
@@ -316,13 +316,13 @@ add_labelled_xlsx_features <- function(supertbl,
 #' Internal helper function. Adds appropriate elements to `wb` object. Returns
 #' a dataframe.
 #'
-#' @param supertbl a supertibble generated using `read_redcap()`
+#' @param supertbl a supertibble generated using [read_redcap()]
 #' @param wb An `openxlsx2` workbook object
 #' @param include_metadata_sheet Include a sheet capturing the combined output of the
 #' supertibble `redcap_metadata`.
 #' @param add_labelled_column_headers Whether or not to include labelled outputs.
 #' @param table_style Any excel table style name or "none" (see "formatting"
-#' vignette in \link[openxlsx2]{wb_add_data_table}). Default "tableStyleLight8".
+#' in [openxlsx2::wb_add_data_table()]). Default "tableStyleLight8".
 #' @param column_width Width to set columns across the workbook. Default
 #' "auto", otherwise a numeric value. Standard Excel is 8.43.
 #' @param na_replace The value used to replace `NA` values in `supertbl`. The default is "".
@@ -400,12 +400,12 @@ add_supertbl_toc <- function(wb,
 #' Internal helper function. Adds appropriate elements to `wb` object. Returns
 #' a dataframe.
 #'
-#' @param supertbl a supertibble generated using `read_redcap()`
+#' @param supertbl a supertibble generated using [read_redcap()]
 #' @param supertbl_meta an `unnest`-ed metadata tibble from the supertibble
 #' @param wb An `openxlsx2` workbook object
 #' @param add_labelled_column_headers Whether or not to include labelled outputs.
 #' @param table_style Any excel table style name or "none" (see "formatting"
-#' vignette in \link[openxlsx2]{wb_add_data_table}). Default "tableStyleLight8".
+#' in [openxlsx2::wb_add_data_table()]). Default "tableStyleLight8".
 #' @param column_width Width to set columns across the workbook. Default
 #' "auto", otherwise a numeric value. Standard Excel is 8.43.
 #' @param na_replace The value used to replace `NA` values in `supertbl`. The default is "".
@@ -442,7 +442,7 @@ add_metadata_sheet <- function(supertbl,
 #' Checks if a supplied supertibble is labelled and throws an error if it is not
 #' but `labelled` is set to `TRUE`
 #'
-#' @param supertbl a supertibble generated using `read_redcap()`
+#' @param supertbl a supertibble generated using [read_redcap()]
 #' @param add_labelled_column_headers Whether or not to include labelled outputs
 #' @param call the calling environment to use in the warning message
 #'
@@ -500,7 +500,7 @@ check_labelled <- function(supertbl, add_labelled_column_headers, call = caller_
 #' This utility function helps to map metadata field types in order to apply
 #' changes in supertbl tables.
 #'
-#' @param supertbl A supertibble generated using `read_redcap()`
+#' @param supertbl A supertibble generated using [read_redcap()]
 #' @param supertbl_meta an `unnest`-ed metadata tibble from the supertibble
 #' @param add_labelled_column_headers Whether or not to include labelled outputs
 #'
@@ -555,7 +555,7 @@ supertbl_recode <- function(supertbl, supertbl_meta, add_labelled_column_headers
 #' Simple helper function for binding supertbl metadata into one table. This
 #' supports creating the metadata XLSX sheet as well as `supertbl_recode`.
 #'
-#' @param supertbl A supertibble generated using `read_redcap()`
+#' @param supertbl A supertibble generated using [read_redcap()]
 #'
 #' @keywords internal
 
